1.0.0
-----

* Repackage to latest boilerplate
* Require i2cdevice>=1.0.0 (now using smbus2 instead of smbus)

0.1.1
-----

* Fix set_proximity_rate_ms, set_light_repeat_rate_ms and set_interrupt_mode (thanks @mkende)
* Improve library comments & docstrings

0.1.0
-----

* Breaking API change to class for CircuitPython compatibility
* Port to new i2cdevice set/get API

0.0.4
-----

* Removed rogue print() of reset status

0.0.3
-----

* Fix PyPi readme formatting

0.0.2
-----

* Added default light-sensor options
* Fixed bugs & linted

0.0.1
-----

* Initial Release
